@@ -9,6 +9,7 @@ from forge.rpc.event import RpcEvent
 from forge.rpc.file import RpcFile
 from forge.rpc.state import RpcState
 from forge.rpc.wallet import RpcWallet
+from forge.rpc.statistic import RpcStatistic
 
 
 class ForgeRpc:
@@ -60,6 +61,10 @@ class ForgeRpc:
         self.list_wallet = self.wallet.list_wallet
         self.declare_node = self.wallet.declare_node
 
+        self.statistic = RpcStatistic(self.chan)
+        self.list_asset_transactions = self.statistic.list_asset_transactions
+        self.list_transactions=self.statistic.list_asset_transactions
+
     def send_itx(self, type_url, itx, wallet, token):
         encoded_itx = utils.encode_to_any(type_url, itx)
         tx = self.create_tx(
@@ -104,7 +109,7 @@ class ForgeRpc:
 
     def get_single_tx_info(self, hash):
         if hash:
-            infos= self.get_tx(hash)
+            infos = self.get_tx(hash)
             info = next(infos)
             if utils.is_proto_empty(info):
                 return None
@@ -123,3 +128,6 @@ class ForgeRpc:
     def get_nonce(self, address):
         account = self.get_single_account_state(address)
         return account.nonce
+
+    def multisig_consume_asset_tx(self, tx, wallet, token, data):
+        return self.multisig(tx, wallet, token, data=data)
